@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003, 2004, 2005, 2006, 2009, 2012 Vidyut Samanta and Christian Grothoff
+     (C) 2002-2013 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -35,7 +35,7 @@ extern "C" {
  * 0.2.6-1 => 0x00020601
  * 4.5.2-0 => 0x04050200
  */
-#define EXTRACTOR_VERSION 0x01010000
+#define EXTRACTOR_VERSION 0x01020000
 
 #include <stdio.h>
 
@@ -98,7 +98,7 @@ enum EXTRACTOR_MetaFormat
 
     /**
      * 0-terminated string.  The specific encoding is unknown.
-     * "data_len" is strlen(data)+1.
+     * "data_len" is strlen (data)+1.
      */
     EXTRACTOR_METAFORMAT_C_STRING = 3
 
@@ -108,8 +108,11 @@ enum EXTRACTOR_MetaFormat
 /**
  * Enumeration defining various sources of keywords.  See also
  * http://dublincore.org/documents/1998/09/dces/
+ *
+ * @defgroup types meta data types
+ * @{
  */
-enum EXTRACTOR_MetaType 
+enum EXTRACTOR_MetaType
   {
     /* fundamental types */
     EXTRACTOR_METATYPE_RESERVED = 0,
@@ -123,7 +126,7 @@ enum EXTRACTOR_MetaType
     EXTRACTOR_METATYPE_BOOK_EDITION = 6,
     EXTRACTOR_METATYPE_BOOK_CHAPTER_NUMBER = 7,
     EXTRACTOR_METATYPE_JOURNAL_NAME = 8,
-    EXTRACTOR_METATYPE_JOURNAL_VOLUME = 9,    
+    EXTRACTOR_METATYPE_JOURNAL_VOLUME = 9,
     EXTRACTOR_METATYPE_JOURNAL_NUMBER = 10,
     EXTRACTOR_METATYPE_PAGE_COUNT = 11,
     EXTRACTOR_METATYPE_PAGE_RANGE = 12,
@@ -146,7 +149,7 @@ enum EXTRACTOR_MetaType
     EXTRACTOR_METATYPE_URL = 29,
 
     /* "unique" document identifiers */
-    EXTRACTOR_METATYPE_URI = 30, 
+    EXTRACTOR_METATYPE_URI = 30,
     EXTRACTOR_METATYPE_ISRC = 31,
     EXTRACTOR_METATYPE_HASH_MD4 = 32,
     EXTRACTOR_METATYPE_HASH_MD5 = 33,
@@ -178,8 +181,8 @@ enum EXTRACTOR_MetaType
     EXTRACTOR_METATYPE_FORMAT_VERSION = 55,
 
     /* processing history */
-    EXTRACTOR_METATYPE_CREATED_BY_SOFTWARE = 56, 
-    EXTRACTOR_METATYPE_UNKNOWN_DATE = 57, 
+    EXTRACTOR_METATYPE_CREATED_BY_SOFTWARE = 56,
+    EXTRACTOR_METATYPE_UNKNOWN_DATE = 57,
     EXTRACTOR_METATYPE_CREATION_DATE = 58,
     EXTRACTOR_METATYPE_MODIFICATION_DATE = 59,
     EXTRACTOR_METATYPE_LAST_PRINTED = 60,
@@ -220,7 +223,7 @@ enum EXTRACTOR_MetaType
     EXTRACTOR_METATYPE_RESOURCE_TYPE = 92,
     EXTRACTOR_METATYPE_LIBRARY_SEARCH_PATH = 93,
     EXTRACTOR_METATYPE_LIBRARY_DEPENDENCY = 94,
-    
+
     /* photography specifics */
     EXTRACTOR_METATYPE_CAMERA_MAKE = 95,
     EXTRACTOR_METATYPE_CAMERA_MODEL = 96,
@@ -241,8 +244,8 @@ enum EXTRACTOR_MetaType
     EXTRACTOR_METATYPE_MAGNIFICATION = 111,
 
     /* image specifics */
-    EXTRACTOR_METATYPE_IMAGE_DIMENSIONS = 112, 
-    EXTRACTOR_METATYPE_PRODUCED_BY_SOFTWARE = 113, 
+    EXTRACTOR_METATYPE_IMAGE_DIMENSIONS = 112,
+    EXTRACTOR_METATYPE_PRODUCED_BY_SOFTWARE = 113,
     EXTRACTOR_METATYPE_THUMBNAIL = 114,
     EXTRACTOR_METATYPE_IMAGE_RESOLUTION = 115,
     EXTRACTOR_METATYPE_SOURCE = 116,
@@ -304,8 +307,8 @@ enum EXTRACTOR_MetaType
     EXTRACTOR_METATYPE_POPULARITY_METER = 168,
     EXTRACTOR_METATYPE_LICENSEE = 169,
     EXTRACTOR_METATYPE_MUSICIAN_CREDITS_LIST = 170,
-    EXTRACTOR_METATYPE_MOOD = 171, 
-    EXTRACTOR_METATYPE_SUBTITLE = 172, 
+    EXTRACTOR_METATYPE_MOOD = 171,
+    EXTRACTOR_METATYPE_SUBTITLE = 172,
 
     /* GNUnet specific values (never extracted) */
     EXTRACTOR_METATYPE_GNUNET_DISPLAY_TYPE = 173,
@@ -383,6 +386,7 @@ enum EXTRACTOR_MetaType
     EXTRACTOR_METATYPE_LAST = 228
   };
 
+/** @} */ /* end of meta data types */
 
 /**
  * Get the textual name of the keyword.
@@ -390,7 +394,8 @@ enum EXTRACTOR_MetaType
  * @param type meta type to get a UTF-8 string for
  * @return NULL if the type is not known, otherwise
  *         an English (locale: C) string describing the type;
- *         translate using 'dgettext ("libextractor", rval)'
+ *         translate using `dgettext ("libextractor", rval)`
+ * @ingroup types
  */
 const char *
 EXTRACTOR_metatype_to_string (enum EXTRACTOR_MetaType type);
@@ -402,7 +407,8 @@ EXTRACTOR_metatype_to_string (enum EXTRACTOR_MetaType type);
  * @param type meta type to get a UTF-8 description for
  * @return NULL if the type is not known, otherwise
  *         an English (locale: C) string describing the type;
- *         translate using 'dgettext ("libextractor", rval)'
+ *         translate using `dgettext ("libextractor", rval)`
+ * @ingroup types
  */
 const char *
 EXTRACTOR_metatype_to_description (enum EXTRACTOR_MetaType type);
@@ -412,6 +418,7 @@ EXTRACTOR_metatype_to_description (enum EXTRACTOR_MetaType type);
  * Return the highest type number, exclusive as in [0,max).
  *
  * @return highest legal metatype number for this version of libextractor
+ * @ingroup types
  */
 enum EXTRACTOR_MetaType
 EXTRACTOR_metatype_get_max (void);
@@ -427,13 +434,13 @@ EXTRACTOR_metatype_get_max (void);
  *        used in the main libextractor library and yielding
  *        meta data).
  * @param type libextractor-type describing the meta data
- * @param format basic format information about data 
- * @param data_mime_type mime-type of data (not of the original file);
+ * @param format basic format information about @a data
+ * @param data_mime_type mime-type of @a data (not of the original file);
  *        can be NULL (if mime-type is not known)
  * @param data actual meta-data found
- * @param data_len number of bytes in data
+ * @param data_len number of bytes in @a data
  * @return 0 to continue extracting, 1 to abort
- */ 
+ */
 typedef int (*EXTRACTOR_MetaDataProcessor) (void *cls,
 					    const char *plugin_name,
 					    enum EXTRACTOR_MetaType type,
@@ -458,31 +465,31 @@ struct EXTRACTOR_ExtractContext
    * Configuration string for the plugin.
    */
   const char *config;
-  
+
   /**
-   * Obtain a pointer to up to 'size' bytes of data from the file to process.
+   * Obtain a pointer to up to @a size bytes of data from the file to process.
    *
-   * @param cls the 'cls' member of this struct
+   * @param cls the @e cls member of this struct
    * @param data pointer to set to the file data, set to NULL on error
    * @param size maximum number of bytes requested
-   * @return number of bytes now available in data (can be smaller than 'size'),
+   * @return number of bytes now available in @a data (can be smaller than @a size),
    *         -1 on error
    */
   ssize_t (*read) (void *cls,
 		   void **data,
 		   size_t size);
 
-  
+
   /**
-   * Seek in the file.  Use 'SEEK_CUR' for whence and 'pos' of 0 to
+   * Seek in the file.  Use `SEEK_CUR` for @a whence and @a pos of 0 to
    * obtain the current position in the file.
-   * 
-   * @param cls the 'cls' member of this struct
+   *
+   * @param cls the @e cls member of this struct
    * @param pos position to seek (see 'man lseek')
    * @param whence how to see (absolute to start, relative, absolute to end)
    * @return new absolute position, -1 on error (i.e. desired position
    *         does not exist)
-   */ 
+   */
   int64_t (*seek) (void *cls,
 		   int64_t pos,
 		   int whence);
@@ -490,10 +497,10 @@ struct EXTRACTOR_ExtractContext
 
   /**
    * Determine the overall size of the file.
-   * 
-   * @param cls the 'cls' member of this struct
-   * @return overall file size, UINT64_MAX on error (i.e. IPC failure)
-   */ 
+   *
+   * @param cls the @a cls member of this struct
+   * @return overall file size, `UINT64_MAX` on error (i.e. IPC failure)
+   */
   uint64_t (*get_size) (void *cls);
 
   /**
@@ -517,7 +524,7 @@ typedef void (*EXTRACTOR_extract_method) (struct EXTRACTOR_ExtractContext *ec);
  * Linked list of extractor plugins.  An application builds this list
  * by telling libextractor to load various keyword-extraction
  * plugins. Libraries can also be unloaded (removed from this list,
- * see EXTRACTOR_plugin_remove).
+ * see #EXTRACTOR_plugin_remove).
  */
 struct EXTRACTOR_PluginList;
 
@@ -526,13 +533,13 @@ struct EXTRACTOR_PluginList;
  * Load the default set of plugins.  The default can be changed
  * by setting the LIBEXTRACTOR_LIBRARIES environment variable;
  * If it is set to "env", then this function will return
- * EXTRACTOR_plugin_add_config (NULL, env, flags). 
+ * #EXTRACTOR_plugin_add_config (NULL, env, flags).
  *
  * If LIBEXTRACTOR_LIBRARIES is not set, the function will attempt
- * to locate the installed plugins and load all of them. 
+ * to locate the installed plugins and load all of them.
  * The directory where the code will search for plugins is typically
  * automatically determined; it can be specified explicitly using the
- * "LIBEXTRACTOR_PREFIX" environment variable.  
+ * "LIBEXTRACTOR_PREFIX" environment variable.
  *
  * This environment variable must be set to the precise directory with
  * the plugins (i.e. "/usr/lib/libextractor", not "/usr").  Note that
@@ -543,7 +550,7 @@ struct EXTRACTOR_PluginList;
  * @param flags options for all of the plugins loaded
  * @return the default set of plugins, NULL if no plugins were found
  */
-struct EXTRACTOR_PluginList * 
+struct EXTRACTOR_PluginList *
 EXTRACTOR_plugin_add_defaults (enum EXTRACTOR_Options flags);
 
 
@@ -583,7 +590,7 @@ EXTRACTOR_plugin_add_config (struct EXTRACTOR_PluginList *prev,
 			     const char *config,
 			     enum EXTRACTOR_Options flags);
 
-		
+
 /**
  * Remove a plugin from a list.
  *
@@ -601,7 +608,7 @@ EXTRACTOR_plugin_remove (struct EXTRACTOR_PluginList *prev,
  *
  * @param plugin the list of plugins
  */
-void 
+void
 EXTRACTOR_plugin_remove_all (struct EXTRACTOR_PluginList *plugins);
 
 
@@ -609,12 +616,12 @@ EXTRACTOR_plugin_remove_all (struct EXTRACTOR_PluginList *plugins);
  * Extract keywords from a file using the given set of plugins.
  *
  * @param plugins the list of plugins to use
- * @param filename the name of the file, can be NULL if data is not NULL
+ * @param filename the name of the file, can be NULL if @a data is not NULL
  * @param data data of the file in memory, can be NULL (in which
  *        case libextractor will open file) if filename is not NULL
- * @param size number of bytes in data, ignored if data is NULL
+ * @param size number of bytes in @a data, ignored if @a data is NULL
  * @param proc function to call for each meta data item found
- * @param proc_cls cls argument to proc
+ * @param proc_cls cls argument to @a proc
  */
 void
 EXTRACTOR_extract (struct EXTRACTOR_PluginList *plugins,
@@ -626,23 +633,23 @@ EXTRACTOR_extract (struct EXTRACTOR_PluginList *plugins,
 
 
 /**
- * Simple EXTRACTOR_MetaDataProcessor implementation that simply
+ * Simple #EXTRACTOR_MetaDataProcessor implementation that simply
  * prints the extracted meta data to the given file.  Only prints
  * those keywords that are in UTF-8 format.
- * 
- * @param handle the file to write to (stdout, stderr), must NOT be NULL,
- *               must be of type "FILE *".
+ *
+ * @param handle the file to write to (`stdout`, `stderr`), must NOT be NULL,
+ *               must be of type `FILE *`.
  * @param plugin_name name of the plugin that produced this value
  * @param type libextractor-type describing the meta data
- * @param format basic format information about data 
- * @param data_mime_type mime-type of data (not of the original file);
+ * @param format basic format information about data
+ * @param data_mime_type mime-type of @a data (not of the original file);
  *        can be NULL (if mime-type is not known)
  * @param data actual meta-data found
- * @param data_len number of bytes in data
+ * @param data_len number of bytes in @a data
  * @return non-zero if printing failed, otherwise 0.
  */
-int 
-EXTRACTOR_meta_data_print (void * handle,
+int
+EXTRACTOR_meta_data_print (void *handle,
 			   const char *plugin_name,
 			   enum EXTRACTOR_MetaType type,
 			   enum EXTRACTOR_MetaFormat format,
