@@ -1,6 +1,6 @@
 /*
      This file is part of libextractor.
-     (C) 2002, 2003, 2004, 2005, 2006, 2009 Vidyut Samanta and Christian Grothoff
+     (C) 2002, 2003, 2004, 2005, 2006, 2009, 2012 Vidyut Samanta and Christian Grothoff
 
      libextractor is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -21,10 +21,19 @@
 #include "platform.h"
 #include "extractor.h"
 
+/**
+ * Description for meta data categories in LE.
+ */
 struct MetaTypeDescription
 {
+  /**
+   * Short (typically 1-word) description.
+   */
   const char *short_description;
-
+  
+  /**
+   * More detailed description.
+   */
   const char *long_description;
 };
 
@@ -435,6 +444,110 @@ static const struct MetaTypeDescription meta_type_descriptions[] = {
   /* 180 */
   { gettext_noop ("original filename"),
     gettext_noop ("name of the original file (reserved for GNUnet)") },
+  { gettext_noop ("disc count"),
+    gettext_noop ("count of discs inside collection this disc belongs to") },
+  { gettext_noop ("codec"),
+    gettext_noop ("codec the data is stored in") },
+  { gettext_noop ("video codec"),
+    gettext_noop ("codec the video data is stored in") },
+  { gettext_noop ("audio codec"),
+    gettext_noop ("codec the audio data is stored in") },
+  /* 185 */
+  { gettext_noop ("subtitle codec"),
+    gettext_noop ("codec/format the subtitle data is stored in") },
+  { gettext_noop ("container format"),
+    gettext_noop ("container format the data is stored in") },
+  { gettext_noop ("bitrate"),
+    gettext_noop ("exact or average bitrate in bits/s") },
+  { gettext_noop ("nominal bitrate"),
+    gettext_noop ("nominal bitrate in bits/s. The actual bitrate might be different from this target bitrate.") },
+  { gettext_noop ("minimum bitrate"),
+    gettext_noop ("minimum bitrate in bits/s") },
+  /* 190 */
+  { gettext_noop ("maximum bitrate"),
+    gettext_noop ("maximum bitrate in bits/s") },
+  { gettext_noop ("serial"),
+    gettext_noop ("serial number of track") },
+  { gettext_noop ("encoder"),
+    gettext_noop ("encoder used to encode this stream") },
+  { gettext_noop ("encoder version"),
+    gettext_noop ("version of the encoder used to encode this stream") },
+  { gettext_noop ("track gain"),
+    gettext_noop ("track gain in db") },
+  /* 195 */
+  { gettext_noop ("track peak"),
+    gettext_noop ("peak of the track") },
+  { gettext_noop ("album gain"),
+    gettext_noop ("album gain in db") },
+  { gettext_noop ("album peak"),
+    gettext_noop ("peak of the album") },
+  { gettext_noop ("reference level"),
+    gettext_noop ("reference level of track and album gain values") },
+  { gettext_noop ("location name"),
+    gettext_noop ("human readable descriptive location of where the media has been recorded or produced") },
+  /* 200 */
+  { gettext_noop ("location elevation"),
+    gettext_noop ("geo elevation of where the media has been recorded or produced in meters according to WGS84 (zero is average sea level)") },
+  { gettext_noop ("location horizontal error"),
+    gettext_noop ("represents the expected error on the horizontal positioning in meters") },
+  { gettext_noop ("location movement speed"),
+    gettext_noop ("speed of the capturing device when performing the capture. Represented in m/s") },
+  { gettext_noop ("location movement direction"),
+    gettext_noop ("indicates the movement direction of the device performing the capture of a media. It is represented as degrees in floating point representation, 0 means the geographic north, and increases clockwise") },
+  { gettext_noop ("location capture direction"),
+    gettext_noop ("indicates the direction the device is pointing to when capturing a media. It is represented as degrees in floating point representation, 0 means the geographic north, and increases clockwise") },
+  /* 205 */
+  { gettext_noop ("show episode number"),
+    gettext_noop ("number of the episode within a season/show") },
+  { gettext_noop ("show season number"),
+    gettext_noop ("number of the season of a show/series") },
+  { gettext_noop ("grouping"),
+    gettext_noop ("groups together media that are related and spans multiple tracks. An example are multiple pieces of a concerto") },
+  { gettext_noop ("device manufacturer"),
+    gettext_noop ("manufacturer of the device used to create the media") },
+  { gettext_noop ("device model"),
+    gettext_noop ("model of the device used to create the media") },
+  /* 210 */
+  { gettext_noop ("audio language"),
+    gettext_noop ("language of the audio track") },
+  { gettext_noop ("channels"),
+    gettext_noop ("number of audio channels") },
+  { gettext_noop ("sample rate"),
+    gettext_noop ("sample rate of the audio track") },
+  { gettext_noop ("audio depth"),
+    gettext_noop ("number of bits per audio sample") },
+  { gettext_noop ("audio bitrate"),
+    gettext_noop ("bitrate of the audio track") },
+  /* 215 */
+  { gettext_noop ("maximum audio bitrate"),
+    gettext_noop ("maximum audio bitrate") },
+  { gettext_noop ("video dimensions"),
+    gettext_noop ("width and height of the video track (WxH)") },
+  { gettext_noop ("video depth"),
+    gettext_noop ("numbers of bits per pixel") },
+  { gettext_noop ("frame rate"),
+    gettext_noop ("number of frames per second (as D/N or floating point)") },
+  { gettext_noop ("pixel aspect ratio"),
+    gettext_noop ("pixel aspect ratio (as D/N)") },
+  /* 220 */
+  { gettext_noop ("video bitrate"),
+    gettext_noop ("video bitrate") },
+  { gettext_noop ("maximum video bitrate"),
+    gettext_noop ("maximum video bitrate") },
+  { gettext_noop ("subtitle language"),
+    gettext_noop ("language of the subtitle track") },
+  { gettext_noop ("video language"),
+    gettext_noop ("language of the video track") },
+  { gettext_noop ("table of contents"),
+    gettext_noop ("chapters, contents or bookmarks (in xml format)") },
+  /* 225 */
+  { gettext_noop ("video duration"),
+    gettext_noop ("duration of a video stream") },
+  { gettext_noop ("audio duration"),
+    gettext_noop ("duration of an audio stream") },
+  { gettext_noop ("subtitle duration"),
+    gettext_noop ("duration of a subtitle stream") },
+
   { gettext_noop ("last"),
     gettext_noop ("last") }
 };
@@ -454,9 +567,9 @@ static const struct MetaTypeDescription meta_type_descriptions[] = {
  *         translate using 'dgettext ("libextractor", rval)'
  */
 const char *
-EXTRACTOR_metatype_to_string(enum EXTRACTOR_MetaType type)
+EXTRACTOR_metatype_to_string (enum EXTRACTOR_MetaType type)
 {
-  if ((type < 0) || (type >= HIGHEST_METATYPE_NUMBER))
+  if ( (type < 0) || (type >= HIGHEST_METATYPE_NUMBER) )
     return NULL;
   return meta_type_descriptions[type].short_description;
 }
@@ -471,9 +584,9 @@ EXTRACTOR_metatype_to_string(enum EXTRACTOR_MetaType type)
  *         translate using 'dgettext ("libextractor", rval)'
  */
 const char *
-EXTRACTOR_metatype_to_description(enum EXTRACTOR_MetaType type)
+EXTRACTOR_metatype_to_description (enum EXTRACTOR_MetaType type)
 {
-  if ((type < 0) || (type >= HIGHEST_METATYPE_NUMBER))
+  if ( (type < 0) || (type >= HIGHEST_METATYPE_NUMBER) )
     return NULL;
   return meta_type_descriptions[type].long_description;
 }
